# remirepo/Fedora spec file for php-laminas-di3
#
# Copyright (c) 2015-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global bootstrap    0
%global gh_commit    ee4d80f1756cf8c249e6816513f6f1f9ed89a262
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     laminas
%global gh_project   laminas-di
%global zf_name      zend-di
%global php_home     %{_datadir}/php
%global namespace    Laminas
%global library      Di
%global major        3
%if %{bootstrap}
%global with_tests   0%{?_with_tests:1}
%else
%global with_tests   0%{!?_without_tests:1}
%endif

Name:           php-%{gh_project}%{major}
Version:        3.1.2
Release:        1%{?dist}
Summary:        Laminas Framework %{library} component v%{major}

License:        BSD
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        %{gh_commit}/%{name}-%{version}-%{gh_short}.tgz
Source1:        makesrc.sh

BuildArch:      noarch
# Tests
%if %{with_tests}
BuildRequires:  php(language) >= 5.5
BuildRequires:  php-reflection
BuildRequires:  php-pcre
BuildRequires:  php-spl
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-autoloader(%{gh_owner}/laminas-stdlib)               >= 3.0   with php-autoloader(%{gh_owner}/laminas-stdlib)               < 4)
BuildRequires: (php-autoloader(%{gh_owner}/laminas-zendframework-bridge) >= 1.0   with php-autoloader(%{gh_owner}/laminas-zendframework-bridge) < 2)
BuildRequires: (php-composer(psr/container)                              >= 1.0   with php-composer(psr/container)                              < 2)
BuildRequires: (php-composer(psr/log)                                    >= 1.0   with php-composer(psr/log)                                    < 2)
# From composer, "require-dev": {
#        "container-interop/container-interop": "^1.2.0",
#        "laminas/laminas-coding-standard": "~1.0.0",
#        "laminas/laminas-servicemanager": "^3.0",
#        "mikey179/vfsstream": "^1.6.7",
#        "phpunit/phpunit": "^7.5.18 || ^8.5"
BuildRequires: (php-composer(container-interop/container-interop)        >= 1.2   with php-composer(container-interop/container-interop)        < 2)
BuildRequires: (php-autoloader(%{gh_owner}/laminas-servicemanager)       >= 3.0   with php-autoloader(%{gh_owner}/laminas-servicemanager)       < 4)
BuildRequires: (php-composer(mikey179/vfsstream)                         >= 1.6.7 with php-composer(mikey179/vfsstream)                         < 2)
# remirepo:7
%else
BuildRequires:  php-laminas-stdlib
BuildRequires:  php-laminas-zendframework-bridge
BuildRequires:  php-psr-container
BuildRequires:  php-PsrLog
BuildRequires:  php-container-interop
BuildRequires:  php-laminas-servicemanager
BuildRequires:  php-mikey179-vfsstream
%endif
BuildRequires:  phpunit8 >= 8.5
%endif
# Autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer, "require": {
#        "php": "^7.1",
#        "laminas/laminas-stdlib": "^2.7 || ^3.0",
#        "laminas/laminas-zendframework-bridge": "^0.4.5 || ^1.0",
#        "psr/container": "^1.0",
#        "psr/log": "^1.0"
Requires:       php(language) >= 5.7
%if ! %{bootstrap}
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:      (php-autoloader(%{gh_owner}/laminas-stdlib)               >= 3.0   with php-autoloader(%{gh_owner}/laminas-stdlib)               < 4)
Requires:      (php-autoloader(%{gh_owner}/laminas-zendframework-bridge) >= 1.0   with php-autoloader(%{gh_owner}/laminas-zendframework-bridge) < 2)
Requires:      (php-composer(psr/container)                              >= 1.0   with php-composer(psr/container)                              < 2)
Requires:      (php-composer(psr/log)                                    >= 1.0   with php-composer(psr/log)                                    < 2)
# From composer, "require": {
#        "laminas/laminas-servicemanager": "An IoC container without auto wiring capabilities"
Suggests:       php-autoloader(%{gh_owner}/laminas-servicemanager)
# remirepo:6
%else
Requires:       php-laminas-stdlib
Requires:       php-laminas-zendframework-bridge
Requires:       php-psr-container
Requires:       php-PsrLog
%endif
%endif
# Autoloader
Requires:       php-composer(fedora/autoloader)
# From phpcompatinfo report for version 3.1.2
Requires:       php-reflection
Requires:       php-pcre
Requires:       php-spl

# Compatibily ensure by the bridge
Obsoletes:      php-zendframework-%{zf_name}%{major}      < 3.1.2-99
Provides:       php-zendframework-%{zf_name}%{major}      = %{version}-99
Provides:       php-composer(%{gh_owner}/%{gh_project})   = %{version}
Provides:       php-composer(zendframework/%{zf_name})    = %{version}
Provides:       php-autoloader(%{gh_owner}/%{gh_project}) = %{version}
Provides:       php-autoloader(zendframework/%{zf_name})  = %{version}


%description
%{gh_project} is an example of an Inversion of Control (IoC) container.
IoC containers are widely used to create object instances that have all
dependencies resolved and injected. Dependency Injection containers are
one form of IoC – but not the only form.

Documentation: https://docs.laminas.dev/%{gh_project}/


%prep
%setup -q -n %{gh_project}-%{gh_commit}

mv LICENSE.md LICENSE

: Fix installation layout
mv templates src/
sed -e 's:/../../templates:/../templates:' -i src/CodeGenerator/*php


%build
: Create autoloader
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{php_home}/%{namespace}/Stdlib/autoload.php',
    '%{php_home}/Psr/Container/autoload.php',
    '%{php_home}/Psr/Log/autoload.php',
]);
\Fedora\Autoloader\Dependencies::optional([
    '%{php_home}/%{namespace}/ServiceManager/autoload.php',
]);
EOF

cat << 'EOF' | tee zf.php
<?php
require_once '%{php_home}/Fedora/Autoloader/autoload.php';
\Fedora\Autoloader\Dependencies::required([
    '%{php_home}/%{namespace}/ZendFrameworkBridge/autoload.php',
    dirname(dirname(__DIR__)) . '/%{namespace}/%{library}%{major}/autoload.php',
]);
EOF


%install
: Laminas library
mkdir -p   %{buildroot}%{php_home}/%{namespace}/
cp -pr src %{buildroot}%{php_home}/%{namespace}/%{library}%{major}

: Zend equiv
mkdir -p      %{buildroot}%{php_home}/Zend/%{library}%{major}
cp -pr zf.php %{buildroot}%{php_home}/Zend/%{library}%{major}/autoload.php


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require_once '%{buildroot}%{php_home}/%{namespace}/%{library}%{major}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('%{namespace}Test\\%{library}\\', dirname(__DIR__) . '/test');
\Fedora\Autoloader\Dependencies::required([
    '%{php_home}/Interop/Container/autoload.php',
    '%{php_home}/org/bovigo/vfs/autoload.php',
]);
EOF

: ignore test failing, only related to output order
ret=0
for cmd in php php72 php73 php74; do
  if which $cmd; then
    $cmd %{_bindir}/phpunit8 \
      --filter '^((?!(testGenerateForClassWithoutParams|testGenerateForClassWithParams)).)*$' \
      --verbose || ret=1
  fi
done

: check compat autoloader
php -r '
require "%{buildroot}%{php_home}/Zend/%{library}%{major}/autoload.php";
exit (class_exists("\\Zend\\%{library}\\Config") ? 0 : 1);
'

exit $ret
%else
: Test suite disabled
%endif


%files
# remirepo:1
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{php_home}/Zend/%{library}%{major}
%{php_home}/%{namespace}/%{library}%{major}


%changelog
* Thu Jan 23 2020 Remi Collet <remi@remirepo.net> - 3.1.2-1
- update to 3.1.2
- rename to php-laminas-di3
- move to /usr/share/php/Laminas/Di3
- raise dependency on PHP 7.1
- add dependency on psr/container
- add dependency on psr/log

* Fri Jan 17 2020 Remi Collet <remi@remirepo.net> - 2.6.1-2
- cleanup

* Tue Jan  7 2020 Remi Collet <remi@remirepo.net> - 2.6.1-1
- switch to Laminas

* Thu Feb 28 2019 Remi Collet <remi@remirepo.net> - 2.6.1-8
- use range dependencies

* Tue Dec  5 2017 Remi Collet <remi@remirepo.net> - 2.6.1-4
- switch from zend-loader to fedora/autoloader

* Tue Apr 26 2016 Remi Collet <remi@fedoraproject.org> - 2.6.1-1
- update to 2.6.1

* Wed Feb 24 2016 Remi Collet <remi@fedoraproject.org> - 2.6.0-1
- update to 2.6.0
- add dependency on container-interop/container-interop
- raise dependency on zend-code >= 2.6
- raise dependency on zend-stdlib >= 2.7

* Tue Aug  4 2015 Remi Collet <remi@fedoraproject.org> - 2.5.1-1
- initial package
